@@ -206,24 +206,19 @@ bool Binder::reload(ScriptCompiler *img)
 #ifdef  SCRIPT_DEFINE_TOKENS
         const char *const *list = server->getList("definitions");
 
-	if(Bayonne::provision_defines)
+        img->compileDefinitions("site.def");
+        while(list && *list)
+        {
+               	img->compileDefinitions(*list);
+               	++list;
+        }
+	cp = server->getLast("location");
+	if(cp)
 	{
-        	img->compileDefinitions("site.def");
-        	while(list && *list)
-        	{
-                	img->compileDefinitions(*list);
-                	++list;
-        	}
-		cp = server->getLast("location");
-		if(cp)
-		{
-			snprintf(buffer, sizeof(buffer), "macros-%s.def", cp);
-			img->compileDefinitions(buffer);
-		}
-		img->compileDefinitions("macros.def");
+		snprintf(buffer, sizeof(buffer), "macros-%s.def", cp);
+		img->compileDefinitions(buffer);
 	}
-	else
-		img->compileDefinitions("provision.def");
+	img->compileDefinitions("macros.def");
 
 #endif
 
