@@ -118,14 +118,6 @@ public:
 	static timeout_t exec_timer;
 	static unsigned compile_count;
 	static volatile bool image_loaded;
-	static bool provision_defines;
-	static bool provision_daemon;
-	static bool provision_system;
-	static bool provision_check;
-	static bool provision_user;
-	static bool provision_test;
-	static const char *provision_server;
-	static const char *provision_libexec;
 
 	static Audio::Encoding peer_encoding;
 	static Audio::timeout_t peer_framing;
@@ -133,8 +125,6 @@ public:
 	static const char *init_voicelib;
 	static AtomicCounter libexec_count;
 
-	static const char *getKeypath(const char *cp);
-
 	/**
 	 * Telephony endpoint interface identifiers.
 	 */ 
@@ -897,6 +887,8 @@ public:
 	static bool loadAudio(const char *path);
 
 	static void errlog(const char *level, const char *fmt, ...); 
+
+	static bool getUserdata(void);
 };
 
 /**
@@ -1388,6 +1380,12 @@ public:
 	static inline BayonneDriver *getPrimary(void)
 		{return firstDriver;}
 	
+	/**
+	 * Get next driver...
+	 */
+	inline BayonneDriver *getNext(void)
+		{return nextDriver;};
+
 
 	/**
 	 * Return primary protocol driver...
