@@ -33,9 +33,9 @@ bool BayonneSession::stateInitial(Event *event)
 	case ENTER_STATE:
 		setState(STATE_IDLE);
 		return true;
+	default:
+		return false;
 	}
-
-	return false;
 }
 
 bool BayonneSession::stateLibexec(Event *event)
@@ -128,7 +128,8 @@ timer:
 		libClose("902 TIMEOUT\n\n");
 		state.pid = 0;
 		newTid();
-		break;
+	default:
+		return enterCommon(event);
         case DROP_LIBEXEC:
 		if(!state.pid)
 			return false;
@@ -168,9 +169,7 @@ timer:
 			advance();
 		setRunning();
 		return true;		
-
 	}
-	return enterCommon(event);
 }
 		
 bool BayonneSession::stateLibwait(Event *event)
@@ -180,7 +179,7 @@ bool BayonneSession::stateLibwait(Event *event)
 	case TIMER_EXPIRED:
 	case ENTER_STATE:
 #ifdef	HAVE_LIBEXEC
-		if(++libexec_count <= state.wait.count || !state.wait.count)
+		if((unsigned)(++libexec_count) <= state.wait.count || !state.wait.count)
 		{
 			if(!BayonneSysexec::create(this))
 			{
@@ -201,8 +200,9 @@ bool BayonneSession::stateLibwait(Event *event)
 		setRunning();
 		return true;
 #endif
+	default:
+		return enterCommon(event);
 	}
-	return enterCommon(event);
 }
 
 bool BayonneSession::stateLibreset(Event *event)
@@ -223,9 +223,9 @@ bool BayonneSession::stateLibreset(Event *event)
 			return true;
 		setRunning();
 		return true;
+	default:
+		return enterCommon(event);
 	}
-
-	return enterCommon(event);
 }
 
 bool BayonneSession::stateIdleReset(Event *event)
@@ -247,8 +247,9 @@ bool BayonneSession::stateIdleReset(Event *event)
 		return true;
 	case MAKE_IDLE:
 		return true;
+	default:
+		return false;
 	}
-	return false;
 }
 
 bool BayonneSession::stateReset(Event *event)
@@ -282,8 +283,9 @@ restart:
 		goto restart;
 	case MAKE_IDLE:
 		return true;
+	default:
+		return false;
 	}
-	return false;
 }
 
 bool BayonneSession::stateRelease(Event *event)
@@ -308,8 +310,9 @@ release:
 		goto release;
 	case MAKE_IDLE:
 		return true;
+	default:
+		return false;
 	}
-	return false;
 }
 
 bool BayonneSession::stateStart(Event *event)
@@ -349,8 +352,9 @@ bool BayonneSession::stateStart(Event *event)
 	case CHILD_RUNNING:
 		advance();
 		return true;
+	default:
+		return enterCommon(event);
 	}
-	return enterCommon(event);
 }
 
 bool BayonneSession::stateWaitkey(Event *event)
@@ -381,8 +385,9 @@ gotkey:
 		advance();
 		setRunning();
 		return true;
+	default:
+		return enterCommon(event);
 	}
-	return enterCommon(event);
 }
 
 bool BayonneSession::stateSleep(Event *event)
@@ -399,8 +404,9 @@ bool BayonneSession::stateSleep(Event *event)
 		advance();
 		setRunning();
 		return true;
+	default:
+		return enterCommon(event);
 	}
-	return enterCommon(event);
 }
 
 bool BayonneSession::stateClear(Event *event)
@@ -423,8 +429,9 @@ bool BayonneSession::stateClear(Event *event)
 		advance();
 		setRunning();
 		return true;
+	default:
+		return enterCommon(event);
 	}
-	return enterCommon(event);
 }	
 
 bool BayonneSession::stateCollect(Event *event)
@@ -513,9 +520,9 @@ input:
 			setSymbol(state.input.var, data, state.input.size);
 		setRunning();
 		return true;
+	default:
+		return enterCommon(event);
 	}
-
-	return enterCommon(event);
 }
 
 bool BayonneSession::stateInput(Event *event)
@@ -639,6 +646,8 @@ input:
 		}
 		advance();
 		goto finish;
+	default:
+		break;
 	}
 
 	return enterCommon(event);
@@ -730,6 +739,8 @@ bool BayonneSession::stateRead(Event *event)
 		}
 		advance();
 		goto finish;
+	default:
+		break;
 	}
 
 	return enterCommon(event);
@@ -821,9 +832,9 @@ bool BayonneSession::stateInkey(Event *event)
 		if(state.inkey.menu)
 			if(scriptEvent("menukey:timeout"))
 				goto finish;
-		break;
+	default:
+		return enterCommon(event);
 	}
-	return enterCommon(event);
 
 finish:
 	setRunning();
@@ -858,20 +869,19 @@ bool BayonneSession::stateTone(Event *event)
 	case LINE_HANGUP:
 		if(state.tone.flashing)
 			return false;
-		break;
+	default:
+		return enterCommon(event);
 	case START_FLASH:
 		state.tone.flashing = true;
 		setOffhook(false);
-		break;
+		return enterCommon(event);
 	case STOP_FLASH:
 		setOffhook(true);
 		state.tone.flashing = false;
-		break;
+		return enterCommon(event);
 	case TONE_START:
 		return false;
 	}
-
-	return enterCommon(event);
 }
 
 bool BayonneSession::stateDTMF(Event *event)
@@ -940,7 +950,8 @@ failed:
                 s = getSid(state.tone.sessionid);
                 if(s)
                         s->queEvent(&cancel);
-		break;
+	default:
+		return enterCommon(event);
 	case TIMER_EXPIRED:
 		memset(&cancel, 0, sizeof(cancel));
 		cancel.id = CANCEL_CHILD;
@@ -949,8 +960,6 @@ failed:
 			s->queEvent(&cancel);		
 		return false;
         }
-
-        return enterCommon(event);
 }
 
 bool BayonneSession::statePlay(Event *event)
@@ -1015,7 +1024,8 @@ exitkey:
                         setRunning();
                         return true;
                 }
-		break;
+	default:
+		return enterCommon(event);
 	case AUDIO_IDLE:
 	case TIMER_EXPIRED:
 		if(setLibreset(RESULT_COMPLETE))
@@ -1025,8 +1035,6 @@ exitkey:
 		setRunning();
 		return true;
 	}
-
-        return enterCommon(event);
 }
 
 void BayonneSession::renameRecord(void)
@@ -1076,6 +1084,7 @@ bool BayonneSession::stateRecord(Event *event)
 		path = audio.getFilename(state.audio.list[0], true);
                 remove(path);
 		state.audio.list[1] = 0;
+	default:
 		break;
 	case AUDIO_IDLE:
 		renameRecord();
@@ -1154,6 +1163,7 @@ exitkey:
 			setRunning();
 			return true;
 		}
+	default:
 		break;
 	case AUDIO_IDLE:
 		if(setLibreset(RESULT_COMPLETE))
@@ -1212,6 +1222,7 @@ bool BayonneSession::stateJoin(Event *event)
 		break;
 	case TIMER_EXPIRED:
 		pid = PART_EXPIRED;
+	default:
 		break;
 	case PART_EXITING:
 		msg = "part:exiting";
@@ -1272,8 +1283,9 @@ bool BayonneSession::stateWait(Event *event)
 		state.timeout = 0;
 		setState(STATE_JOIN);
 		return true;
+	default:
+	        return enterCommon(event);
 	}
-        return enterCommon(event);
 }
 
 bool BayonneSession::stateHold(Event *event)
@@ -1287,8 +1299,9 @@ bool BayonneSession::stateHold(Event *event)
 		error("hold-failed");
 		setRunning();
 		return true;
+	default:
+		return enterCommon(event);
 	}
-	return enterCommon(event);
 }
 
 bool BayonneSession::stateRecall(Event *event)
@@ -1302,8 +1315,9 @@ bool BayonneSession::stateRecall(Event *event)
                 error("recall-failed");    
                 setRunning();
                 return true;
-        }
-        return enterCommon(event); 
+	default:
+	        return enterCommon(event); 
+	}
 }
 
 bool BayonneSession::stateXfer(Event *event)
@@ -1339,8 +1353,9 @@ bool BayonneSession::stateXfer(Event *event)
 	case TIMER_EXPIRED:
 		setState(STATE_HANGUP);
 		return true;
+	default:
+		return enterCommon(event);
 	}
-	return enterCommon(event);
 }
 
 bool BayonneSession::stateDial(Event *event)
@@ -1382,8 +1397,9 @@ bool BayonneSession::stateDial(Event *event)
 		return true;
 	case TONE_START:
 		return true;
-	}	
-        return enterCommon(event);
+	default:	
+	        return enterCommon(event);
+	}
 }
 
 bool BayonneSession::stateBusy(Event *event)
@@ -1438,8 +1454,9 @@ bool BayonneSession::stateRinging(Event *event)
 			setState(STATE_PICKUP);
 		}
 		return true;
+	default:
+		return enterCommon(event);		
 	}
-	return enterCommon(event);		
 }
 
 bool BayonneSession::stateIdle(Event *event)
@@ -1514,6 +1531,7 @@ attach:
 				BayonneDriver::add(this);
 				return false;
 			}
+		default:
 			break;
 		}
 		if(attachStart(event))
@@ -1526,9 +1544,9 @@ attach:
 		BayonneDriver::add(this);
 		type = NONE;
 		return true;
+	default:
+		return enterCommon(event);
 	}
-
-	return enterCommon(event);
 }
 
 bool BayonneSession::statePickup(Event *event)
@@ -1553,9 +1571,9 @@ bool BayonneSession::statePickup(Event *event)
 		return true;
 	case LINE_DISCONNECT:
 		return true;
+	default:
+		return enterCommon(event);
 	}
-
-	return enterCommon(event);
 }		
 
 bool BayonneSession::stateSeize(Event *event)
@@ -1666,10 +1684,10 @@ failed:
 		return true;
 	case LINE_DISCONNECT:
 		return true;
+	default:
+		return enterCommon(event);
 	}
 
-	return enterCommon(event);
-
 dialer:
 	snprintf(evtname, sizeof(evtname), "reject:%s", state.join.dial);
 	if(digitEvent(evtname))
@@ -1730,9 +1748,9 @@ bool BayonneSession::stateRunning(Event *event)
 		else
 			setSymbol("script.error", "none");
 		return true;
+	default:
+		return enterCommon(event);
 	}
-
-	return enterCommon(event);
 }
 
 bool BayonneSession::stateThreading(Event *event)
@@ -1751,10 +1769,9 @@ bool BayonneSession::stateThreading(Event *event)
 		return true;
 	case TIMER_EXPIRED:	// use common handler...
 		slog.debug("%s: thread expired", logname);
-		break;
-        }
-
-        return enterCommon(event);
+	default:
+	        return enterCommon(event);
+	}
 }
 
 bool BayonneSession::stateHangup(Event *event) 
@@ -1825,9 +1842,9 @@ bool BayonneSession::stateHangup(Event *event)
 		setOffhook(false);
 		startTimer(timer);
 		return true;
-        }
-
-        return enterCommon(event);
+        default:
+	        return enterCommon(event);
+	}
 }
 
 bool BayonneSession::filterPosting(Event *event)
@@ -1891,9 +1908,9 @@ bool BayonneSession::filterPosting(Event *event)
 		if(!pid || pid != event->pid)
 			return false;
 		strcpy(var_pid, "none");
+	default:
 		return true;	
 	}
-	return true;
 }
 
 bool BayonneSession::enterCommon(Event *event)
@@ -2157,9 +2174,9 @@ childerr:
 			}
 
 		return false;
-
+	default:
+		return false;
 	}
-	return false;
 }	
 
 bool BayonneSession::enterInitial(Event *event)
