@@ -59,12 +59,6 @@ static Keydata::Define driver[] = {
 #endif
         {NULL, NULL}};
 
-#ifdef	WIN32
-#define	KEYS	"/bayonne/sip"
-#else
-#define	KEYS	"/bayonne/driver/sip"
-#endif
-
 Driver Driver::sip;
 
 bool Registry::isActive(void)
@@ -89,25 +83,16 @@ void Registry::add(ScriptImage *img)
 }
 
 Driver::Driver() :
-BayonneDriver(driver, KEYS, "sip", false),
+BayonneDriver(driver, "/bayonne/driver/sip", "sip", false),
 Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 {
 	const char *cp, *p;
 	char buf[1024];
 
-#ifdef	WIN32
-	const char *env = Process::getEnv("DRIVERCONFIG");
-
-	if(env)
-		loadFile(env, "sip");
-#else
-	if(Bayonne::provision_system)
-		load("/bayonne/provision/sip");
-	else if(Bayonne::provision_user)
+	if(getUserdata())
 		load("~bayonne/sip");
-#endif
-	sip_port = 5060;
 
+	sip_port = 5060;
 
 	cp = getLast("ack");
 	if(!cp)
