@@ -416,6 +416,10 @@ failure:
 			data_payload = 8;
 			rtpmap = "a=rtpmap:8 PCMA/8000/1";
 			break;
+		case g721ADPCM:
+			data_payload = 5;
+			rtpmap = "a=rtpmap:5 G726_32/8000/1";
+			break;
 		case gsmVoice:
 			data_payload = 3;
 			rtpmap = "a=rtpmap:3 GSM/8000/1";
@@ -688,6 +692,9 @@ const char *Session::checkAudio(bool live)
 
 	switch(info.encoding)
 	{
+	case g721ADPCM:
+		audio.libext = ".adpcm";
+		break;
 	case alawAudio:
 		audio.libext = ".al";
 		break;
