@@ -160,6 +160,16 @@ sub detach($$) {
 	}
 }
 
+sub error($$) {
+	my($self,$msg) = @_;
+	my($tsid) = $self->{'tsession'};
+
+	if($tsid) {
+		print STDOUT "$tsid error $msg\n";
+		$self->{'tsession'} = undef;
+	}
+}
+
 sub post($$$) {
 	my($self, $id, $value) = @_;
 	my $sid = $self->{head}{'SESSION'};
