@@ -114,14 +114,9 @@ static Keydata::Define urlkeys[] = {
 	{"agent", "bayonne/" VERSION},
 	{NULL, NULL}};
 
-#ifdef	WIN32
-Keydata keypaths(paths, "/bayonne/paths");
-Keydata keyserver(server, "/bayonne/server");
-Keydata keyengine(engine, "/bayonne/engine");
-BayonneConfig keylibexec("libexec", libkeys, "/bayonne/libexec");
-BayonneConfig keysmtp("smtp", smtpkeys, "/bayonne/smtp");
-BayonneConfig keyurl("url", urlkeys, "/bayonne/url");
-#else
+bool flag_daemon = false;
+bool flag_check = false;
+
 Keydata keypaths(paths, "/bayonne/server/paths");
 Keydata keyserver(server, "/bayonne/server/server");
 Keydata keyengine(engine, "/bayonne/server/engine");
@@ -129,7 +124,6 @@ BayonneConfig keylibexec("libexec", libkeys, "/bayonne/server/libexec");
 BayonneConfig keysmtp("smtp", smtpkeys, "/bayonne/server/smtp");
 BayonneConfig keyurl("url", urlkeys, "/bayonne/server/url");
 
-#endif
 Keydata keyoptions;
 
 void liveConfig(void)
@@ -139,6 +133,7 @@ void liveConfig(void)
 	const char *env;
 	char *p, *sp, *tok;
 	const char *cp;
+	bool ttsdef = false, libdef = false;
 	unsigned timeslots = atoi(keyengine.getLast("timeslots"));
 	Bayonne::timeslot_t overdraft = 1;
 
@@ -182,7 +177,6 @@ void liveConfig(void)
 	keyserver.setValue("node", nodename);
 	keyserver.setValue("platform", "w32");
 	keyserver.setValue("cpu", cpu);
-
 #else
 	struct utsname uts;
 	char hostname[128];
@@ -239,8 +233,8 @@ void liveConfig(void)
 
 	if(sp && !stricmp(sp, "off"))
 	{
+		libdef = ttsdef = true;
 		sp = NULL;
-		Bayonne::provision_defines = false;
 	}
 
         if(sp && !*sp)
@@ -256,15 +250,23 @@ void liveConfig(void)
                         setString(path, sizeof(path), cp);
                 else
                         snprintf(path, sizeof(path), "%s.def", cp);
+		if(!stricmp(path, "libexec.def"))
+			libdef = true;
+		if(!stricmp(path, "tts.def"))
+			ttsdef = true;
                 runtime.setValue("definitions", path);
                 cp = strtok_r(NULL, " ,;:\t", &tok);
         }
 
-	cp = keyoptions.getLast("prefix");
-#ifdef	WIN32
-	if(Bayonne::provision_test)
-		cp = NULL;
+#ifdef	HAVE_LIBEXEC
+	if(!libdef)
+		runtime.setValue("definitions", "libexec.def");
+
+	if(!ttsdef)
+		runtime.setValue("definitions", "tts.def");
 #endif
+
+	cp = keyoptions.getLast("prefix");
 	if(cp && *cp)
 		chdir(cp);
 
@@ -408,47 +410,6 @@ void liveConfig(void)
         Bayonne::allocate(timeslots, dynamic_cast<ScriptCommand *>(&runtime), overdraft); 
 }
 
-#ifdef	HAVE_TESTING
-
-void testConfig(char *argv0)
-{
-#ifdef	WIN32
-	keypaths.setValue("prompts", "../audio");
-	keypaths.setValue("scripts", "../scripts");
-	keypaths.setValue("macros", "../scripts");
-	keypaths.setValue("config", "../config");
-	keypaths.setValue("datafiles", "tempfiles");
-	keypaths.setValue("logfiles", "tempfiles");
-	keypaths.setValue("runfiles", "tempfiles");
-	Process::setEnv("DRIVERCONFIG", "../config/driver.ini", true);
-	Process::setEnv("MODULECONFIG", "../config/module.ini", true);
-	Process::setEnv("SPANCONFIG", "../config/spans.ini", true);
-#else
-	char pbuf[256];
-	getcwd(pbuf, sizeof(pbuf));
-	keyoptions.setValue("prefix", "");
-	keypaths.setValue("libexec", pbuf);
-	keypaths.setValue("btsexec", SOURCE_FILES "/utils/btsexec");
-	keypaths.setValue("prompts", SOURCE_FILES "/audio");
-	keypaths.setValue("scripts", SOURCE_FILES "/scripts");
-	keypaths.setValue("macros", SOURCE_FILES "/scripts");
-	keypaths.setValue("config", SOURCE_FILES "/config");
-	keypaths.setValue("datafiles", SOURCE_FILES "/server/tempfiles");
-	keypaths.setValue("logfiles", SOURCE_FILES "/server/tempfiles");
-	keypaths.setValue("runfiles", SOURCE_FILES "/server/tempfiles");
-#endif
-	Bayonne::provision_test = true;
-	Bayonne::provision_daemon = false;
-	runtime.setValue("virtual.tts", "theta");
-	keypaths.setValue("modexec", "../scripts");
-	Dir::create("tempfiles");
-	keyserver.setValue("state", "test");
-	keyserver.setValue("logging", "debug");
-	keyserver.setValue("monitoring", "no");
-}	
-
-#endif
-
 void loadConfig(void)
 {
 #ifdef	WIN32
@@ -462,7 +423,6 @@ void loadConfig(void)
 	keylibexec.loadFile(pbuf, "libexec");
 	keysmtp.loadFile(pbuf, "smtp");
 	keyurl.loadFile(pbuf, "url");
-	runtime.loadFile(pbuf, "virtual", "virtual");
 
 	snprintf(pbuf, sizeof(pbuf), "%s/driver.ini", config);
 	Process::setEnv("DRIVERCONFIG", pbuf, true); 
@@ -489,26 +449,13 @@ void loadConfig(void)
 	else
 		strcpy(homepath, "tempfiles");
 
-	runtime.loadPrefix("virtual", "/bayonne/server/virtual");
-	if(Bayonne::provision_user)
+	if(Bayonne::getUserdata())
 	{
 		keypaths.load("~bayonne/paths");
 		keyserver.load("~bayonne/server");
 		keyengine.load("~bayonne/engine");
 		keysmtp.load("~bayonne/smtp");
 		keyurl.load("~bayonne/url");
-		runtime.loadPrefix("virtual", "~bayonne/virtual");
-	}
-
-	if(Bayonne::provision_system)
-	{
-		keypaths.load("/bayonne/provision/paths");
-		keyserver.load("/bayonne/provision/server");
-		keyengine.load("/bayonne/provision/engine");
-		keylibexec.load("/bayonne/provision/libexec");
-		keysmtp.load("/bayonne/provision/smtp");
-		keyurl.load("/bayonne/provision/url");
-		runtime.loadPrefix("virtual", "/bayonne/provision/virtual");
 	}
 
 	umask(007);
@@ -567,7 +514,6 @@ bool parseConfig(char **argv)
 	const char *prefix;
 	char *option;
 	char *script = NULL;
-	char *argv0 = *(argv++);
 	char *ext;
 	unsigned scrcount = 0;
 
@@ -582,12 +528,15 @@ bool parseConfig(char **argv)
 	if(cp && atoi(cp) > 0)
 		keyengine.setValue("timeslots", cp);
 #endif
+	++argv;
 
 retry:
 	if(!*argv)
 		goto skip;
 
 	option = *argv;
+
+
         if(!strcmp("--", option))
         {
                 ++argv;
@@ -618,68 +567,18 @@ retry:
                 goto retry;
         }  
 
-#ifdef	HAVE_TESTING
-        if(!strnicmp(option, "-test=", 6))
-        {
-		testConfig(argv0);
-                keyengine.setValue("driver", option + 6);
-                ++argv;
-                goto retry;
-        }  
-	
-	if(!stricmp(option, "-test"))
-	{
-		++argv;
-		if(!*argv)
-		{
-			cerr << "bayonne: -test: missing driver" << endl;
-			exit(-1);
-		}
-		testConfig(argv0);
-		keyengine.setValue("driver", *(argv++));
-		goto retry;
-	}
-
-	if(!strnicmp(option, "-logging=", 9))
-        {
-                keyserver.setValue("logging", option + 9);
-                ++argv;
-                goto retry;
-        }
-
-	if(!strnicmp(option, "-scripts=", 9))
-	{
-		keypaths.setValue("scripts", option + 9);
-		++argv;
-		goto retry;
-	}
-
-	if(!strnicmp(option, "-macros=", 8))
-	{
-		keypaths.setValue("macros", option + 8);
-		++argv;
-		goto retry;
-	} 
-
-        if(!strnicmp(option, "-libexec=", 9))
-        {
-                keypaths.setValue("libexec", option + 9);
-                ++argv;
-                goto retry;
-        }
-#endif            
 
 	if(!stricmp(option, "-check"))
 	{
 		keyserver.setValue("logging", "debug");
-		Bayonne::provision_check = true;
+		flag_check = true;
 		++argv;
 		goto retry;
 	}
 
 	if(!strnicmp(option, "-vvv", 4))
 	{
-		Bayonne::provision_daemon = false;
+		flag_daemon = false;
 		keyserver.setValue("logging", "debug");
 		++argv;
 		goto retry;
@@ -687,7 +586,7 @@ retry:
 
         if(!stricmp(option, "-vv"))
         {
-		Bayonne::provision_daemon = false;
+		flag_daemon = false;
                 keyserver.setValue("logging", "notice");
                 ++argv;
                 goto retry;
@@ -695,7 +594,7 @@ retry:
 
         if(!stricmp(option, "-v"))
         {
-		Bayonne::provision_daemon = false;
+		flag_daemon = false;
                 keyserver.setValue("logging", "error");
                 ++argv;
                 goto retry;
@@ -731,57 +630,6 @@ retry:
                 goto retry;
         }
 
-#ifdef	HAVE_TESTING
-        if(!stricmp(option, "-libexec"))
-        {
-                ++argv;
-                if(!*argv)
-                {
-                        cerr << "bayonne: -libexec: missing argument" << endl;
-                        exit(-1);
-                }
-                keypaths.setValue("libexec", *(argv++));
-                goto retry;
-        }
-
-        if(!stricmp(option, "-scripts"))     
-        {
-                ++argv;
-                if(!*argv)
-                {
-			cerr << "bayonne: -scripts: missing argument" << endl;
-                        exit(-1);
-                }
-                keypaths.setValue("scripts", *(argv++));
-                goto retry;
-        }
-           
-
-        if(!stricmp(option, "-macros"))     
-        {
-                ++argv;
-                if(!*argv)
-                {
-			cerr << "bayonne: -macros: missing argument" << endl;
-                        exit(-1);
-                }
-                keypaths.setValue("macros", *(argv++));
-                goto retry;
-        } 
-
-	if(!stricmp(option, "-logging"))
-        {
-                ++argv;
-                if(!*argv)
-                {
-			cerr << "bayonne: -logging: missing argument" << endl;
-                        exit(-1);
-                }
-                keyserver.setValue("logging", *(argv++));
-                goto retry;
-        }
-#endif
-
         if(!stricmp(option, "-location"))  
         {
                 ++argv;
@@ -955,20 +803,6 @@ skip:
 	return true;
 }		
 
-#ifdef	HAVE_TESTING
-void dumpConfig(Keydata &keydef)
-{
-	unsigned count = keydef.getCount();
-	char **keys = new char *[count + 1];
-	count = keydef.getIndex(keys, count + 1);
-	while(count--)
-	{
-		cout << *keys << " = " << keydef.getLast(*keys) << endl;
-		++keys;
-	}
-}
-#endif
-
 void purgedir(const char *dir)
 {
 	const char *cp;
